import type { Directive } from 'vue';
import type { SFCInstallWithContext, SFCWithInstall } from './typescript';
/**
 * 接收vue组件，给组件挂载install方法，用于全局注册，并且将子组件作为属性挂载到主组件上
 * @param main 组件1
 * @param extra { [name2]: 组件2, [name3]: 组件3... }
 * @returns
 *
 * 如 with(ElButton, { ElButtonGroup })
 * 首先给ElButton和ElButtonGroup挂载install方法，用于全局注册
 * 然后ElButton.ElButtonGroup = ElButtonGroup
 */
export declare const withInstall: <T, E extends Record<string, any>>(main: T, extra?: E | undefined) => SFCWithInstall<T> & E;
/**
 * 注册install方法，给方法挂载_context属性，同时让该方法在全局组件实例上可直接访问
 * @param fn
 * @param name
 * @returns
 * 如 withInstallFunction(message, '$message')
 * message.install = (app) => {
 *  message._context = app._context
 *  app.config.globalProperties.$message = message
 * }
 *
 * 在组件中：
 * import { getCurrentInstance } from 'vue'
 * const { proxy } = getCurrentInstance()
 * proxy.$message.success('xxx')
 */
export declare const withInstallFunction: <T>(fn: T, name: string) => SFCInstallWithContext<T>;
/**
 * 在install方法中注册指令
 * @param directive
 * @param name
 * @returns
 */
export declare const withInstallDirective: <T extends Directive<any, any>>(directive: T, name: string) => SFCWithInstall<T>;
/**
 * 挂载空的install方法
 */
export declare const withNoopInstall: <T>(component: T) => SFCWithInstall<T>;
